@@ -14,7 +14,7 @@ use SNMP ();
 use version ();
 
 
-our $VERSION = "0.200";
+our $VERSION = "0.300";
 
 
 use constant {
@@ -40,6 +40,7 @@ sub spawn {
     my %defaults = (
         Name    => "perl",
         AgentX  => 0,
+        Ping    => 10,
     );
 
     my %args = ( %defaults, @_ );
@@ -57,6 +58,7 @@ sub spawn {
         heap => {
             args        => \%args,
             oid_tree    => {},
+            ping_delay  => $args{Ping},
         },
 
         inline_states => {
@@ -165,9 +167,13 @@ sub ev_register {
 sub ev_agent_check {
     my ($kernel, $heap, $case) = @_[ KERNEL, HEAP, ARG0 ];
 
-    SNMP::_check_timeout();
+    $case ||= "";
+
+    # schedule next check
+    $kernel->delay(agent_check => $heap->{ping_delay}),
 
     # process the incoming data and invoque the callback
+    SNMP::_check_timeout();
     $heap->{agent}->agent_check_and_process(0);
 
     if ($case eq "register") {
@@ -460,7 +466,9 @@ See also in F<eg/> for more ready-to-use examples.
 
 This module is a thin wrapper around C<NetSNMP::agent> to use it within
 a POE-based program, its basic use being the same as you would do
-without POE: C<register> one or more OIDs with their associated callbacks.
+without POE: C<register> one or more OIDs with their associated callbacks,
+then within a callback process & answer the requests with C<setValue()>,
+C<setOID()>, C<setError()>, etc.
 
 C<POE::Component::NetSNMP::agent> also provides a simpler mechanism,
 similar to C<SNMP::Extension::PassPersist>, if you just want to handle
@@ -468,8 +476,13 @@ C<get> and C<getnext> requests over an OID tree: set the C<Autohandle>
 option to the a OID, then add OID entries with C<add_oid_entry> or
 C<add_oid_tree>.
 
+The module will try to automatically recover from a lost connection with
+AgentX master (see the C<Ping> option), but you can force a check by
+C<post>ing to C<agent_check>;
+
 Note that most of the API is available both as POE events and as object
-methods.
+methods, in an attempt to make it a bit easier for people not fully used
+to POE.
 
 This module can use C<Sort::Key::OID> when it is available, for sorting
 OIDs faster than with the internal pure Perl function.
@@ -522,6 +535,11 @@ C<Debug> - I<(optional)> when true, enables debug mode on this session
 
 =item *
 
+C<Ping> - I<(optional)> sets the ping delay between manual agent checks
+in seconds; default is 10 seconds
+
+=item *
+
 C<Errback> - I<(optional)> sets the error callback.
 
 =back
